@@ -1,14 +1,25 @@
 from .dead_letter_queue import DeadLetterQueue
-from .policies.abstract import DeadLetterQueuePolicy, InvalidMessages
+from .policies.abstract import (
+    DeadLetterQueuePolicy,
+    InvalidKafkaMessage,
+    InvalidMessage,
+    InvalidMessages,
+    InvalidRawMessage,
+)
 from .policies.count import CountInvalidMessagePolicy
 from .policies.ignore import IgnoreInvalidMessagePolicy
+from .policies.produce import ProduceInvalidMessagePolicy
 from .policies.raise_e import RaiseInvalidMessagePolicy
 
 __all__ = [
     "DeadLetterQueue",
-    "InvalidMessages",
     "DeadLetterQueuePolicy",
+    "InvalidKafkaMessage",
+    "InvalidMessage",
+    "InvalidMessages",
+    "InvalidRawMessage",
     "CountInvalidMessagePolicy",
     "IgnoreInvalidMessagePolicy",
     "RaiseInvalidMessagePolicy",
+    "ProduceInvalidMessagePolicy",
 ]
